pub struct MemoryConnectionStore { /* private fields */ }Expand description
In-memory connection store that does not persist to disk.
Used for ephemeral connections where the connection should not be saved.
Implementations