Traits for storage implementations
Structs
- Credential
Field Set - Describes which credential fields were included in an approved response.
- NoOp
Audit Log - No-op audit logger that discards all events. Used as the default when no audit logging is configured.
Enums
- Audit
Connection Type - How a new connection was established between devices.
- Audit
Event - Audit events emitted by the [
UserClient] (trusted device) for security-relevant actions.
Traits
- Audit
Log - Persistent audit logging for security-relevant events on the UserClient.
- Identity
Provider - Provides a cryptographic identity for the current client.
- Session
Store - Trait for session cache storage implementations