IdentityProvider

Trait IdentityProvider 

pub trait IdentityProvider: Send + Sync {
    // Required method
    fn identity<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = IdentityKeyPair> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;

    // Provided method
    fn fingerprint<'life0, 'async_trait>(
        &'life0 self,
    ) -> Pin<Box<dyn Future<Output = IdentityFingerprint> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait { ... }
}
Provides a cryptographic identity for the current client.

For the device group, this should be one shared identity, for the single-device, a unique identity. This should be generated on first run and stored persistently, in secure storage where possible.

Required Methods

fn identity<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = IdentityKeyPair> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get the identity keypair

Provided Methods

fn fingerprint<'life0, 'async_trait>( &'life0 self, ) -> Pin<Box<dyn Future<Output = IdentityFingerprint> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get the fingerprint of this identity

Implementors