Protocol types and events Types for the remote client protocol
Structs
- Credential
Data - Credential data returned from a request
Enums
- Client
Action - Connection
Mode - Connection mode for establishing a connection
- Credential
Query - What kind of credential to look up.
- Remote
Client Event - Events emitted by the remote client during connection and operation
- Remote
Client Response - Responses from CLI to RemoteClient