IdentityProvider

Trait IdentityProvider 

pub trait IdentityProvider: Send + Sync {
    // Required method
    fn identity(&self) -> &IdentityKeyPair;

    // Provided method
    fn fingerprint(&self) -> IdentityFingerprint { ... }
}
Provides a cryptographic identity for the current client.

For the device group, this should be one shared identity, for the single-device, a unique identity. This should be generated on first run and stored persistently, in secure storage where possible.

Required Methods

fn identity(&self) -> &IdentityKeyPair

Get reference to the identity keypair

Provided Methods

fn fingerprint(&self) -> IdentityFingerprint

Get the fingerprint of this identity

Implementors