pub trait IdentityProvider: Send + Sync {
// Required method
fn identity(&self) -> &IdentityKeyPair;
// Provided method
fn fingerprint(&self) -> IdentityFingerprint { ... }
}Expand description
Provides a cryptographic identity for the current client.
For the device group, this should be one shared identity, for the single-device, a unique identity. This should be generated on first run and stored persistently, in secure storage where possible.
Required Methods
Sourcefn identity(&self) -> &IdentityKeyPair
fn identity(&self) -> &IdentityKeyPair
Get reference to the identity keypair
Provided Methods
Sourcefn fingerprint(&self) -> IdentityFingerprint
fn fingerprint(&self) -> IdentityFingerprint
Get the fingerprint of this identity