Module types

Module types 

Protocol types and events Types for the remote client protocol

Structs

CredentialData
Credential data returned from a request

Enums

ClientAction
ConnectionMode
Connection mode for establishing a connection
CredentialQuery
What kind of credential to look up.
RemoteClientEvent
Events emitted by the remote client during connection and operation
RemoteClientResponse
Responses from CLI to RemoteClient